@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # ModRana paths handling
@@ -20,11 +19,11 @@
 #---------------------------------------------------------------------------
 
 import os
-import modrana_utils
+import utils
 
 MONAV_DATA_FOLDER_NAME = "monav_data"
 
-class Paths:
+class Paths(object):
   """
   Handle paths to various folders:
   * main profile folder
@@ -43,7 +42,7 @@ class Paths:
     # profile folder
     self.profileFolderPath = self.modrana.getProfilePath()
     # check the profile path and create the folders if necessary
-    modrana_utils.createFolderPath(self.profileFolderPath)
+    utils.createFolderPath(self.profileFolderPath)
 
     # load version string
     self.versionString = None
@@ -55,7 +54,7 @@ class Paths:
   def getProfilePath(self):
     """return path to the profile folder"""
     # check if the path exists and create it if not
-    modrana_utils.createFolderPath(self.profileFolderPath)
+    utils.createFolderPath(self.profileFolderPath)
     return self.profileFolderPath
 
   def getOptionsFilePath(self):
@@ -176,8 +175,8 @@ class Paths:
         versionString = str(versionString)
         self.versionString = versionString
       except Exception, e:
-        print "modRana config: loading version info failed"
-        print e
+        print("modRana config: loading version info failed")
+        print(e)
 
   def _assurePathFolder(self, path, folder):
     """combine the given path and folder and make sure the path exists,
@@ -188,5 +187,5 @@ class Paths:
   def _assurePath(self, path):
     """assure path exists and return it back"""
     # check if the path exists and create it if not
-    modrana_utils.createFolderPath(path)
+    utils.createFolderPath(path)
     return path
\ No newline at end of file
