@@ -80,9 +80,6 @@ class ModRana(object):
     self.mapRotationAngle = 0 # in radians
     self.notMovingSpeed = 1 # in m/s
 
-    # map layers
-    self.mapLayers = {}
-
     # per mode options
     # NOTE: this variable is automatically saved by the
     # options module
@@ -743,13 +740,6 @@ class ModRana(object):
     # return it
     return profileFolderPath
 
-  ## MAP LAYERS ##
-  # map layer information is important and needed by many modules during their initialization,
-  # so it is handled here
-
-  def getMapLayers(self):
-    return self.configs.getMapLayers()
-
   ## STARTUP TIMING ##
 
   def addTime(self, message):
