@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # A SmartQ 7 modRana device-specific module.
@@ -20,16 +19,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_device_module import deviceModule
+from base_device_module import DeviceModule
 
 def getModule(m,d,i):
-  return(device_q7(m,d,i))
+  return DeviceQ7(m,d,i)
 
-class device_q7(deviceModule):
+class DeviceQ7(DeviceModule):
   """A SmartQ 7 modRana device-specific module"""
   
   def __init__(self, m, d, i):
-    deviceModule.__init__(self, m, d, i)
+    DeviceModule.__init__(self, m, d, i)
 
   def getDeviceIDString(self):
     return "q7"
@@ -38,7 +37,7 @@ class device_q7(deviceModule):
     return "Smart Devices SmartQ 7 MID"
 
   def getWinWH(self):
-    return (800,480)
+    return 800,480
 
   def simpleMapDragging(self):
     return True
@@ -47,10 +46,4 @@ class device_q7(deviceModule):
     return True
 
   def getSupportedGUIModuleIds(self):
-    return ["GTK"]
-
-if(__name__ == "__main__"):
-  a = device_example({}, {})
-  a.update()
-  a.update()
-  a.update()
+    return ["GTK"]
\ No newline at end of file
