@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # Base class for Rana GUI modules
@@ -22,12 +21,13 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
 
-from base_module import ranaModule
+from modules.base_module import RanaModule
 
-class GUIModule(ranaModule):
+class GUIModule(RanaModule):
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
+    RanaModule.__init__(self, m, d, i)
     self.msLongPress = 400
+    self.subtypeId = None
 
   def getIDString(self):
     """
@@ -35,6 +35,18 @@ class GUIModule(ranaModule):
     """
     return None
 
+  def getSubtypeId(self):
+    return self.subtypeId
+
+  def setSubtypeId(self, subtypeId):
+    """the subtype id hints to the GUI module, which GUI variant to use
+
+    The GUI module might not respect this, if it either does not support
+    the given variant or it might revert to the default if the given variant fails
+    to start.
+    """
+    self.subtypeId = subtypeId
+
   def resize(self, mrw, h):
     """resize the GUI to given width and height"""
     pass
@@ -44,7 +56,7 @@ class GUIModule(ranaModule):
     pass
 
   def getViewport(self):
-    """return a (x,y,w,h) tupple"""
+    """return a (x,y,w,h) tuple"""
     pass
 
   def setWindowTitle(self, title):
@@ -133,7 +145,7 @@ class GUIModule(ranaModule):
     """handles notifications"""
     return False
 
-  def notify(self, message, msTimeout, icon=""):
+  def notify(self, message, msTimeout=0, icon=""):
     """handle a notification"""
     pass
 
@@ -142,16 +154,12 @@ class GUIModule(ranaModule):
     return "It works!"
 
   def needsLocalhostTileserver(self):
-    """
-    report if the GUI module requires the localhost
-    tileserver to run
-    """
+    """report if the GUI module requires the localhost
+    tileserver to run"""
     return False
 
   def openUrl(self, url):
-    """
-    open a given URL asynchronously
-    """
+    """open a given URL asynchronously"""
     # the webbrowser module should be a good default
     import webbrowser
     webbrowser.open(url)
