@@ -24,6 +24,7 @@ import sys
 import re
 import traceback
 import cStringIO
+from pprint import pprint
 
 # PySide
 from PySide import QtCore
@@ -38,6 +39,8 @@ from modules.gui_modules.base_gui_module import GUIModule
 from datetime import datetime
 import time
 from modules.gui_modules.gui_qml import drawing
+from modules.gui_modules.gui_qml import wrappers
+from modules.gui_modules.gui_qml import list_models
 from core.fix import Fix
 
 global globe
@@ -142,11 +145,18 @@ class QMLGUI(GUIModule):
     # make tile loading accessible from QML
     tiles = MapTiles(self)
     rc.setContextProperty("mapTiles", tiles)
+    # make map layers accessible from QML
+    tiles = MapLayers(self)
+    rc.setContextProperty("mapLayers", tiles)
 
     # make constants accessible
     self.constants = self.getConstants()
     rc.setContextProperty("C", self.constants)
 
+    # #register list models
+    # self._registerListModels()
+
+    # connect to the close event
     self.window.closeEvent = self._qtWindowClosed
     #self.window.show()
 
@@ -154,12 +164,17 @@ class QMLGUI(GUIModule):
 
     self._location = None # location module
     self._mapTiles = None # map tiles module
+    self._mapLayers = None # map tiles module
 
     self._notificationQueue = []
 
   def firstTime(self):
     self._location = self.m.get('location', None)
     self._mapTiles = self.m.get('mapTiles', None)
+    self._mapLayers = self.m.get('mapLayers', None)
+
+    #register list models
+    self._registerListModels()
 
   def getIDString(self):
     return "QML"
@@ -237,9 +252,11 @@ class QMLGUI(GUIModule):
   def stopMainLoop(self):
     """stop the main loop or its equivalent"""
     # notify QML GUI first
-    """NOTE: due to calling Python properties
-    from onDestruction handlers causing
-    segfault, we need this"""
+
+    # NOTE: due to calling Python properties
+    # from onDestruction handlers causing
+    # segfault, we need this
+
     #self.rootObject.shutdown()
 
     # quit the application
@@ -278,6 +295,32 @@ class QMLGUI(GUIModule):
     }
     return C
 
+  def _registerListModel(self, modelName, model):
+    """Register a list model to the QML context
+    :param modelName: a unique name of the model for the QML context
+    :param model: the list model instance
+    """
+    self.view.rootContext().setContextProperty(modelName, model)
+
+  def _registerListModels(self):
+    """Register all list models needed by modRana"""
+
+    # register the layer model
+    ml = self.m.get('mapLayers', None)
+    if ml:
+      # just to make sure that the garbage
+      # collector doesn't eat the list model
+      # we assign it as a class variable
+      wrappedGroupList = map(
+        lambda x: wrappers.MapLayerGroupWrapper(x), ml.getGroupList(sort=True)
+      )
+      self.layersListModel = list_models.BaseListModel(wrappedGroupList)
+      self._registerListModel("mapLayersModel", self.layersListModel)
+
+  def _getLayerListModel(self):
+    pass
+
+
 class Platform(QtCore.QObject):
   """make current platform available to QML and integrable as a property"""
 
@@ -444,13 +487,13 @@ class TileImageProvider(QDeclarativeImageProvider):
     try:
       # split the string provided by QML
       split = tileInfo.split("/")
-      layer = split[0]
+      layerId = split[0]
       z = int(split[1])
       x = int(split[2])
       y = int(split[3])
 
       # get the tile from the tile module
-      tileData = self.gui._mapTiles.getTile(layer, z, x, y)
+      tileData = self.gui._mapTiles.getTile(layerId, z, x, y)
       if not tileData:
         return None
 
@@ -486,25 +529,60 @@ class MapTiles(QtCore.QObject):
       return 0
 
   @QtCore.Slot(str, int, int, int, result=bool)
-  def loadTile(self, layer, z, x, y):
+  def loadTile(self, layerId, z, x, y):
     """
     load a given tile from storage and/or from the network
     True - tile already in storage or in memory
     False - tile download in progress, retry in a while
     """
-    #    print(layer, z, x, y)
-    if self.gui._mapTiles.tileInMemory(layer, z, x, y):
+    #    print(layerId, z, x, y)
+    if self.gui._mapTiles.tileInMemory(layerId, z, x, y):
     #      print("available in memory")
       return True
-    elif self.gui._mapTiles.tileInStorage(layer, z, x, y):
+    elif self.gui._mapTiles.tileInStorage(layerId, z, x, y):
     #      print("available in storage")
       return True
     else: # not in memory or storage
       # add a tile download request
-      self.gui._mapTiles.addTileDownloadRequest(layer, z, x, y)
+      self.gui._mapTiles.addTileDownloadRequest(layerId, z, x, y)
       #      print("downloading, try later")
       return False
 
+class MapLayers(QtCore.QObject):
+  def __init__(self, gui):
+    QtCore.QObject.__init__(self)
+    self.gui = gui
+
+    self._wrappedLayers = None
+    # why are wee keeping our own dictionary of wrapped
+    # layers and not just returning a newly wrapped object on demand ?
+    # -> because PySide (1.1.1) segfaults if we don't hold any reference
+    # on the object returned :)
+
+  @property
+  def wrappedLayers(self):
+    # make sure the wrapped layer dict has benn initialized
+    # (we can't do that at init, as at that time the
+    # map layers module is not yet loaded)
+    if self._wrappedLayers is None:
+      self._wrappedLayers = {}
+      for layerId, layer in self.gui._mapLayers.getLayerDict().iteritems():
+        self.wrappedLayers[layerId] = wrappers.MapLayerWrapper(layer)
+    return self._wrappedLayers
+
+  @QtCore.Slot(str, result=QtCore.QObject)
+  def getLayer(self, layerId):
+    return self.wrappedLayers.get(layerId, None)
+
+  @QtCore.Slot(str, result=str)
+  def getLayerName(self, layerId):
+    layer = self.wrappedLayers.get(layerId, None)
+    if layer:
+      return layer.wo.label
+    else:
+      return "label for %s unknown" % layerId
+
+
 class FixWrapper(QtCore.QObject):
   def __init__(self, fix):
     QtCore.QObject.__init__(self)
