@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # Allows areas of screen to be registered as clickable, sending a message
@@ -18,16 +17,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_module import ranaModule
-from rect import rect
+from modules.base_module import RanaModule
+from core.rectangle import Rectangle
 
 def getModule(m,d,i):
-  return clickHandler(m,d,i)
+  return ClickHandler(m,d,i)
 
-class clickHandler(ranaModule):
+class ClickHandler(RanaModule):
   """handle mouse clicks"""
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
+    RanaModule.__init__(self, m, d, i)
     self.beforeDraw()
     self.ignoreNextClicks = 0
 
@@ -46,20 +45,20 @@ class clickHandler(ranaModule):
   def registerXYWH(self, x1, y1, dx, dy, action, timedAction=None, layer=0):
     if timedAction: # at least one timed action
       self.timedActionInProgress = True
-    area = rect(x1, y1, dx, dy)
+    area = Rectangle(x1, y1, dx, dy)
     self.register(area, action, timedAction, layer)
 
   def registerXYXY(self, x1,y1,x2,y2, action, timedAction=None, layer=0):
     if timedAction: # at least one timed action
       self.timedActionInProgress = True
-    area = rect(x1, y1, x2-x1, y2-y1)
+    area = Rectangle(x1, y1, x2-x1, y2-y1)
     self.register(area, action, timedAction, layer)
 
   def handleClick(self, x, y, msDuration):
-#    print "Clicked at %d,%d for %d" % (x,y,msDuration)
+#    print("Clicked at %d,%d for %d" % (x,y,msDuration))
     if self.ignoreNextClicks > 0:
       self.ignoreNextClicks -= 1
-#      print "ignoring click, %d remaining" % self.ignoreNextClicks
+#      print("ignoring click, %d remaining" % self.ignoreNextClicks)
     else:
       hit = False
       for area in self.layers[2]:
@@ -116,10 +115,10 @@ class clickHandler(ranaModule):
     return hit
 
   def registerDraggable(self, x1, y1, x2, y2, module):
-    self.dragAreas.append((rect(x1, y1, x2-x1, y2-y1), module))
+    self.dragAreas.append((Rectangle(x1, y1, x2-x1, y2-y1), module))
 
   def registerDraggableEntireScreen(self, module):
-    print "Entire screen is draggable for %s " % module
+    print("Entire screen is draggable for %s " % module)
     self.dragScreen = module
 
   def handleDrag(self, startX, startY, dx, dy, x, y, msDuration):
@@ -136,8 +135,4 @@ class clickHandler(ranaModule):
           if m is not None:
             m.dragEvent(startX,startY,dx,dy,x,y)
           else:
-            print "Drag registered to nonexistent module %s" % module
-
-if(__name__ == "__main__"):
-  print "Testing rect"
-  a = clickHandler({},{})
\ No newline at end of file
+            print("Drag registered to nonexistent module %s" % module)
