@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # A module, that provides feedback from the interface to the user.
@@ -18,20 +17,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_module import ranaModule
+from modules.base_module import RanaModule
 
 def getModule(m,d,i):
-  return(interfaceFeedback(m,d,i))
+  return InterfaceFeedback(m,d,i)
 
-class interfaceFeedback(ranaModule):
+class InterfaceFeedback(RanaModule):
   """A sample pyroute module"""
   
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
-    
-
-if(__name__ == "__main__"):
-  a = interfaceFeedback({}, {})
-  a.update()
-  a.update()
-  a.update()
+    RanaModule.__init__(self, m, d, i)
