@@ -20,24 +20,26 @@ from __future__ import with_statement # for python 2.5
 import threading
 from time import sleep, time
 
-from base_position_source import PositionSource, Fix
+from base_position_source import PositionSource
+from core.fix import Fix
+
 
 class GPSD(PositionSource):
-  def __init__(self,location):
-    self.connected = False
+  def __init__(self, location):
     PositionSource.__init__(self, location)
-#  def __init__(self, location):
-#    PositionSource.__init__(location)
+    self.connected = False
+    self.GPSDConsumer = None
+    self.status = "not connected"
 
-  def start(self):
+  def start(self, startMainLoop=False):
     """start the GPSD based location update method"""
     self.connected = False
     try:
       self.GPSDConsumer = GPSDConsumer()
-      self._checkVerbose() # check if verbose debugging is enabled
       self.GPSDConsumer.daemon = True
       self.GPSDConsumer.start()
       self.connected = True
+      self.setGPSDDebug(self.debug) # check if verbose debugging is enabled
     except Exception, e:
       print("location GPSD: connecting to GPSD failed", e)
       self.status = "No GPSD running"
@@ -51,30 +53,48 @@ class GPSD(PositionSource):
   def _updateGPSD(self):
     # only update if connected to GPSD
     if self.connected:
-      fix = self.GPSDConsumer.getFix()
+      fix, sats = self.GPSDConsumer.getBoth()
       if fix:
         """
         as the GPSD consumer updates its values very often, it probably better to use a simple
         tuple instead of a Fix object and only convert to the Fix object once the position data
         is actually requested
         """
-        (lat,lon,elevation,bearing,speed,timestamp) = fix
-        fix = Fix( (lat,lon),
-                   elevation,
-                   bearing,
-                   speed )
-        self.fix = fix
+        #        (lat,lon,elevation,bearing,speed,timestamp) = fix
+        satCount = len(sats)
+        inUseSatCount = len(filter(lambda x: x.used, sats))
 
-  def _checkVerbose(self):
-    verbose = self.location.get('gpsdDebugVerbose', False)
-#    verbose = True
+        modRanaFix = Fix((fix.latitude, fix.longitude),
+                         fix.altitude,
+                         fix.track,
+                         fix.speed,
+                         mode=fix.mode,
+                         climb=fix.climb,
+                         sats=satCount,
+                         sats_in_use=inUseSatCount,
+                         horizontal_accuracy=fix.epx * fix.epy,
+                         # TODO: separate x y accuracy support ?
+                         vertical_accuracy=fix.epv,
+                         speed_accuracy=fix.eps,
+                         climb_accuracy=fix.epc,
+                         bearing_accuracy=fix.epd,
+                         time_accuracy=fix.ept,
+                         gps_time=fix.time
+        )
+        self.fix = modRanaFix
+
+  def setDebug(self, value):
+    self.debug = value
+    self.setGPSDDebug(value)
+
+  def setGPSDDebug(self, verbose):
     if self.GPSDConsumer:
       if verbose:
         self.GPSDConsumer.setVerbose(True)
-        print "location: gpsd debugging output turned ON"
+        print("location: gpsd debugging output turned ON")
       else:
         self.GPSDConsumer.setVerbose(False)
-        print "location: gpsd debugging output turned OFF"
+        print("location: gpsd debugging output turned OFF")
     else:
       print("location: gpsd not used, so there is no debug output to enable")
 
@@ -85,22 +105,22 @@ class GPSD(PositionSource):
 #    try:
 #      self.s.send("%s\r\n" % cmd)
 #    except:
-#        print "something is wrong with the gps daemon"
+#        print("something is wrong with the gps daemon")
 #    result = self.s.recv(8192)
-#    #print "Reply: %s" % result
+#    #print("Reply: %s" % result)
 #    expect = 'GPSD,' + cmd.upper() + '='
 #    if(result[0:len(expect)] != expect):
-#      print "Fail: received %s after sending %s" % (result, cmd)
+#      print("Fail: received %s after sending %s" % (result, cmd))
 #      return(None)
 #    remainder = result[len(expect):]
 #    if(remainder[0:1] == '?'):
-#      print "Fail: Unknown data in " + cmd
+#      print("Fail: Unknown data in " + cmd)
 #      return(None)
 #    return(remainder)
 #
 #  def test_socket(self):
 #    for i in ('i','p','p','p','p'):
-#      print "%s = %s" % (i, self.socket_cmd(i))
+#      print("%s = %s" % (i, self.socket_cmd(i)))
 #      sleep(1)
 #
 #  def gpsStatus(self):
@@ -137,7 +157,7 @@ class GPSD(PositionSource):
 #    for i in range(count):
 #      (prn,el,az,db,used) = [int(a) for a in parts[i+1].split(' ')]
 #      self.set("gps_sat_%d"%i, (db,used,prn))
-#      #print "%d: %d, %d, %d, %d, %d" % (i,prn,el,az,db,used)
+#      #print("%d: %d, %d, %d, %d, %d" % (i,prn,el,az,db,used))
 #
 #  def quality(self):
 #    result = self.socket_cmd('q')
@@ -145,27 +165,31 @@ class GPSD(PositionSource):
 #      (count,dd,dx,dy) = result.split(' ')
 #      count = int(count)
 #      (dx,dy,dd) = [float(a) for a in (dx,dy,dd)]
-#      print "%d sats, quality %f, %f, %f" % (count,dd,dx,dy)
+#      print("%d sats, quality %f, %f, %f" % (count,dd,dx,dy))
 
 class GPSDConsumer(threading.Thread):
   """consume data as they come in from the GPSD and store last known fix"""
+
   def __init__(self):
     threading.Thread.__init__(self)
     self.lock = threading.RLock()
     self.stop = False
     import gps_module as gps
+
     self.session = gps.gps(host="localhost", port="2947")
     self.session.stream(flags=gps.client.WATCH_JSON)
     self.verbose = False
     # vars
     self.fix = None
+    self.satellites = []
 
   def run(self):
     import gps_module as gps
+
     print("GPSDConsumer: starting\n")
     while True:
       if self.stop == True:
-        print "GPSDConsumer: breaking\n"
+        print("GPSDConsumer: breaking\n")
         break
       try:
         self.session.next() # this function blocks until a new fix is available
@@ -173,12 +197,20 @@ class GPSDConsumer(threading.Thread):
         print("GPSD: error: GPS daemon not running")
         print(e)
       sf = self.session.fix
-      if sf.mode != gps.MODE_NO_FIX:
+      if sf.mode > 1: # 0 & 1 -> no fix
         with self.lock:
-          self.fix = (sf.latitude,sf.longitude,sf.altitude,sf.track,sf.speed, time())
+          self.fix = sf
+          self.satellites = self.session.satellites
+          #          self.fix = (sf.latitude,sf.longitude,sf.altitude,sf.track,sf.speed, time())
           if self.verbose:
-#          if 1:
-            print self.fix
+          #          if 1:
+            try:
+              print('GPSD fix debug')
+              print(
+              'mode:' + str(sf.mode) + ' lat,lon:' + str((sf.latitude, sf.longitude)) + ' elev:' + str(sf.altitude))
+            except  Exception, e:
+              print('ERROR debugging GPSD fix')
+              print(e)
       else:
         if self.verbose:
           print("GPSDConsumer: NO FIX, will retry in 1 s")
@@ -200,6 +232,14 @@ class GPSDConsumer(threading.Thread):
     with self.lock:
       return self.fix
 
+  def getSatellites(self):
+    with self.lock:
+      return
+
+  def getBoth(self):
+    with self.lock:
+      return self.fix, self.satellites
+
   def setVerbose(self, value):
     with self.lock:
       self.verbose = value
\ No newline at end of file
