@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # A modRana built-in tileserver
@@ -24,17 +23,17 @@ import random
 from threading import Thread
 import urllib2
 import cStringIO
-from base_module import ranaModule
+from modules.base_module import RanaModule
 import tileserver_callback_proxy
 
 def getModule(m,d,i):
   return(Tileserver(m,d,i))
 
-class Tileserver(ranaModule):
+class Tileserver(RanaModule):
   """A modRana built-in tileserver"""
   
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
+    RanaModule.__init__(self, m, d, i)
 
     tileserver_callback_proxy.cb = self
 
@@ -51,7 +50,7 @@ class Tileserver(ranaModule):
 
 
   def runServer(self):
-    print "tile server: starting localhost tileserver"
+    print("tile server: starting localhost tileserver")
 
 
     self.port = 9009
@@ -66,6 +65,7 @@ class Tileserver(ranaModule):
       self.httpd = Server(("", self.tileserverPort), self)
     except Exception, e:
       print("tileserver: starting server on port %d failed" % self.port)
+      print(e)
       self.port = random.randint(9000,10000)
       print("tileserver: generating random port")
       print("tileserver: starting on port %d" % self.port)
@@ -120,8 +120,8 @@ class Server(SocketServer.TCPServer):
       z = int(split[2])
       x = int(split[3])
       y = int(split[4].split(".")[0])
-      print self.path
-      print tileserver_callback_proxy.cb._mapTiles
+      print(self.path)
+      print(tileserver_callback_proxy.cb._mapTiles)
       try:
         tileData = tileserver_callback_proxy.cb._mapTiles.getTile(layer, z, x, y)
         if tileData:
@@ -147,9 +147,3 @@ class Server(SocketServer.TCPServer):
 
   def finish_request(self, request, client_address):
     self.Proxy(request, client_address)
-
-if(__name__ == "__main__"):
-  a = Example({}, {})
-  a.update()
-  a.update()
-  a.update()
