@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 #----------------------------------------------------------------------------
 # Log position as GPX, draw the track traveled
@@ -18,14 +17,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
+from modules.base_module import RanaModule
 import shutil
-from base_module import ranaModule
 import glob
 import time
 import os
 from collections import deque
-import geo
-import way
+from core import geo
+from core import way
 from core import gs
 
 if gs.GUIString == "GTK":
@@ -44,12 +43,12 @@ DONT_ADD_TO_TRACE_THRESHOLD = 1
 
 
 def getModule(m,d,i):
-  return(tracklog(m,d,i))
+  return Tracklog(m,d,i)
 
-class tracklog(ranaModule):
+class Tracklog(RanaModule):
   """Record tracklogs"""
   def __init__(self, m, d, i):
-    ranaModule.__init__(self, m, d, i)
+    RanaModule.__init__(self, m, d, i)
     self.loggingEnabled = False
     self.loggingPaused = False
     self.loggingStartTimestamp = None
@@ -98,7 +97,7 @@ class tracklog(ranaModule):
         self.initLog()
       # or resume an existing one
       elif self.loggingEnabled == True & self.loggingPaused == True:
-        print "tracklog: resuming the logging"
+        print("tracklog: resuming the logging")
         self.loggingPaused = False
       self.set('needRedraw', True)
 
@@ -127,7 +126,7 @@ class tracklog(ranaModule):
       self.pxpyIndex=[]
 
     elif message == 'setupColorMenu':
-      m = self.m.get('showGPX', None)
+      m = self.m.get('showTracklogs', None)
       if m:
         m.setupChooseDistColorMenu('tracklog', '|tracklog:colorFromRegister|set:menu:None')
 
@@ -275,12 +274,12 @@ class tracklog(ranaModule):
       self.log1.flush()
     except Exception, e:
       print('tracklog: saving primary temporary log failed')
-      print e
+      print(e)
     try:
       self.log2.flush()
     except Exception, e:
       print('tracklog: saving secondary temporary log failed')
-      print e
+      print(e)
 
   def generateLogName(self):
     """generate a unique name for a log"""
@@ -391,18 +390,18 @@ class tracklog(ranaModule):
 #    # get only the points, that are currently visible
 #    proj = self.m.get('projection', None)
 #    if proj:
-#      print self.LatLonIndex
+#      print(self.LatLonIndex)
 #      (lat1,lon1,lat2,lon2) = proj.screenBBoxLL()
-#      print (lat1,lon1,lat2,lon2)
-#      print "filtering"
+#      print((lat1,lon1,lat2,lon2))
+#      print("filtering")
 #      # first get only point for available latitude range
 #      visiblePoints = filter(lambda x: lat1 >= x[0] >= lat2, self.LatLonIndex)
-#      print visiblePoints
+#      print(visiblePoints)
 #      visiblePoints = filter(lambda x: lon1 <= x[1] <= lon2, visiblePoints)
-#      print visiblePoints
+#      print(visiblePoints)
 #      # now sort the list of visible points according to the index
 #      visiblePoints = sorted(visiblePoints, key=lambda x: x[2])
-#      print visiblePoints
+#      print(visiblePoints)
 #      return visiblePoints
 
   def point(self, cr, x, y):
@@ -631,8 +630,8 @@ class tracklog(ranaModule):
           
       # draw a track to current position (if known):
 
-#      print z, modulo
-#      print counter, drawCount
+#      print(z, modulo)
+#      print(counter, drawCount)
 
       cr.stroke()
       cr.fill()
